"""Flask app for What Format."""

from flask import Flask, jsonify, render_template, request
from flask_caching import Cache
from whatformat.util import whatdateformat

# pylint: disable=invalid-name ; These variables are standard for Flask.
app = Flask(__name__)
cache = Cache(app, config={'CACHE_TYPE': 'simple'})


@app.route('/')
@cache.cached(query_string=True)
def landing():
    """Render the homepage."""
    date_string = request.args.get('date')
    return render_template('landing.html', date_string=date_string)


@app.route('/date')
@cache.cached(query_string=True)
def date():
    """Return date format strings matching date_string."""
    date_string = request.args.get('date')
    return jsonify(whatdateformat.get_unique_format_strings(date_string))
